==> mx-cleanup_23.11.tar.xz: BUILD/translations/mx-cleanup_el.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="el">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="14"/>
        <location filename="../mainwindow.cpp" line="81"/>
        <location filename="../mainwindow.cpp" line="502"/>
        <source>MX Cleanup</source>
        <translation>MX Καθαρισμός</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="59"/>
        <source>Display help </source>
        <translation>Εμφάνιση βοήθειας </translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="62"/>
        <source>Help</source>
        <translation>Βοήθεια</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="69"/>
        <source>Alt+H</source>
        <translation>Alt+H</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="98"/>
        <source>About this application</source>
        <translation>Περί της εφαρμογής</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="101"/>
        <source>About...</source>
        <translation>Περί...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="108"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="140"/>
        <source>Quit application</source>
        <translation>Κλείσιμο εφαρμογής</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="143"/>
        <location filename="../mainwindow.cpp" line="586"/>
        <source>Close</source>
        <translation>Κλείσιμο</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="150"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="188"/>
        <source>Apply</source>
        <translation>Εφαρμογή</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="216"/>
        <source>Empty Trash</source>
        <translation>Άδειασμα απορριμμάτων</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="222"/>
        <source>Trash older than:</source>
        <translation>Απορρίμματα παλαιότερα από:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="235"/>
        <location filename="../mainwindow.ui" line="372"/>
        <location filename="../mainwindow.ui" line="590"/>
        <source>Don&apos;t empty</source>
        <translation>Μην αδειάζετε</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="245"/>
        <location filename="../mainwindow.ui" line="622"/>
        <location filename="../mainwindow.ui" line="724"/>
        <location filename="../mainwindow.cpp" line="364"/>
        <location filename="../mainwindow.cpp" line="367"/>
        <location filename="../mainwindow.cpp" line="371"/>
        <source> days</source>
        <translation> ημέρες</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="264"/>
        <source>All users</source>
        <translation>Ολοι οι χρήστες</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="283"/>
        <source>Selected user</source>
        <translation>Επιλεγμένος χρήστης</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="331"/>
        <source>Clear APT Cache</source>
        <translation>Εκκαθάριση προσωρινής μνήμης πακέτων</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="343"/>
        <source>Old files</source>
        <translation>Παλιά αρχεία</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="362"/>
        <source>All files</source>
        <translation>Όλα τα αρχεία</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="404"/>
        <source>Graphical Tool for Analyzing Disk Usage</source>
        <translation>Γραφικό εργαλείο για την ανάλυση χρήσης του δίσκου</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="416"/>
        <source>Run Disk Usage Analyzer</source>
        <translation>Εκτέλεση του αναλυτή χρήσης του δίσκου</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="430"/>
        <source>Schedule</source>
        <translation>Πρόγραμμα</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="442"/>
        <source>No automatic clean</source>
        <translation>Χωρίς προγραμματισμένο καθαρισμό</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="449"/>
        <source>At reboot</source>
        <translation>Σε επανεκκίνηση</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="456"/>
        <source>Daily</source>
        <translation>Καθημερινά</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="463"/>
        <source>Weekly</source>
        <translation>Εβδομαδιαία</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="470"/>
        <source>Monthly</source>
        <translation>Μηνιαία</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="499"/>
        <source>Free Disk Space for User</source>
        <translation>Απελευθέρωση χώρου</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="511"/>
        <location filename="../mainwindow.ui" line="527"/>
        <source>Select user to repair</source>
        <translation>Επιλέξτε χρήστη για την απελευθέρωση χώρου</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="514"/>
        <source>Select user:</source>
        <translation>Επιλογή χρήστη:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="543"/>
        <source>Delete Logs</source>
        <translation>Διαγραφή αρχείων καταγραφής</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="568"/>
        <source>All logs</source>
        <translation>Όλα τα αρχεία καταγραφής</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="606"/>
        <source>Old logs</source>
        <translation>Παλιά αρχεία καταγραφής</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="641"/>
        <source>Logs older than:</source>
        <translation>Αρχεία καταγραφής παλαιότερα από:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="664"/>
        <source>Kernel removal tool</source>
        <translation>Εργαλείο αφαίρεσης πυρήνα</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="676"/>
        <source>List and select kernels to remove</source>
        <translation>Λίστα και επιλογή πυρήνων για αφαίρεση</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="696"/>
        <source>Clean Flatpak</source>
        <translation>Εκκαθάριση Flatpak</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="702"/>
        <source>Remove unused runtimes</source>
        <translation>Αφαίρεση αχρησιμοποίητων runtimes</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="718"/>
        <source>Clean Folders</source>
        <translation>Εκκαθάριση φακέλων</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="737"/>
        <source>Not accessed for:</source>
        <translation>Χωρίς πρόσβαση για:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="805"/>
        <source>All (potentially dangerous)</source>
        <translation>Όλα (πιθανά επικίνδυνο)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="206"/>
        <source>Press any key to close</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="364"/>
        <location filename="../mainwindow.cpp" line="368"/>
        <location filename="../mainwindow.cpp" line="372"/>
        <source> day</source>
        <translation> ημέρα</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="494"/>
        <source>Done</source>
        <translation>Ολοκληρώθηκε</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="495"/>
        <source>Cleanup command done</source>
        <translation>Ο καθαρισμός ολοκληρώθηκε</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="495"/>
        <source>%1 MiB were freed</source>
        <translation>Απελευθερώθηκαν %1 MiB</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="502"/>
        <source>About</source>
        <translation>Περί</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="503"/>
        <source>Version: </source>
        <translation>Έκδοση: </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="505"/>
        <source>Quick and safe removal of old files</source>
        <translation>Γρήγορη και ασφαλής αφαίρεση παλιών αρχείων</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="507"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Πνευματικά δικαιώματα (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="508"/>
        <source>%1 License</source>
        <translation>Άδεια %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="515"/>
        <source>%1 Help</source>
        <translation>Βοήθεια %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="581"/>
        <source>Kernel currently in use: &lt;b&gt;%1&lt;/b&gt;</source>
        <translation>Πυρήνας σε χρήση: &lt;b&gt;%1&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="584"/>
        <source>Remove selected</source>
        <translation>Αφαίρεση επιλεγμένων</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="589"/>
        <source>Similar kernels that can be removed:</source>
        <translation>Παρόμοιοι πυρήνες που μπορούν να αφαιρεθούν:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="590"/>
        <source>Other kernels that can be removed:</source>
        <translation>Άλλοι πυρήνες που μπορούν να αφαιρεθούν:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="592"/>
        <source>&lt;b&gt;Nothing to remove.&lt;/b&gt; Cannot remove kernel in use.</source>
        <translation>&lt;b&gt;Τίποτα για αφαίρεση.&lt;/b&gt; Δεν μπορεί να αφαιρεθεί ο πυρήνας σε χρήση.</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../about.cpp" line="51"/>
        <source>License</source>
        <translation>Άδεια</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="52"/>
        <location filename="../about.cpp" line="62"/>
        <source>Changelog</source>
        <translation>Αρχείο αλλαγών</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="53"/>
        <source>Cancel</source>
        <translation>Ακύρωση</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="75"/>
        <source>&amp;Close</source>
        <translation>&amp;Κλείσιμο</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="54"/>
        <source>Quick safe removal of old files</source>
        <translation>Γρήγορη και ασφαλής αφαίρεση των παλιών αρχείων</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="81"/>
        <location filename="../main.cpp" line="89"/>
        <source>Error</source>
        <translation>Σφάλμα</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="82"/>
        <source>You seem to be logged in as root, please log out and log in as normal user to use this program.</source>
        <translation>Φαίνεται ότι έχετε συνδεθεί ως διαχειριστής, αποσυνδεθείτε και συνδεθείτε ως απλός χρήστης για να χρησιμοποιήσετε αυτό το πρόγραμμα.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="90"/>
        <source>You must run this program with admin access.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> mx-cleanup_24.4.01.tar.xz: BUILD/translations/mx-cleanup_el.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="el">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="14"/>
        <location filename="../mainwindow.cpp" line="82"/>
        <location filename="../mainwindow.cpp" line="519"/>
        <source>MX Cleanup</source>
        <translation>MX Καθαρισμός</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="59"/>
        <source>Display help </source>
        <translation>Εμφάνιση βοήθειας </translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="62"/>
        <source>Help</source>
        <translation>Βοήθεια</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="69"/>
        <source>Alt+H</source>
        <translation>Alt+H</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="98"/>
        <source>About this application</source>
        <translation>Περί της εφαρμογής</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="101"/>
        <source>About...</source>
        <translation>Περί...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="108"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="140"/>
        <source>Quit application</source>
        <translation>Κλείσιμο εφαρμογής</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="143"/>
        <location filename="../mainwindow.cpp" line="600"/>
        <source>Close</source>
        <translation>Κλείσιμο</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="150"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="188"/>
        <source>Apply</source>
        <translation>Εφαρμογή</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="216"/>
        <source>Empty Trash</source>
        <translation>Άδειασμα απορριμμάτων</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="222"/>
        <source>Trash older than:</source>
        <translation>Απορρίμματα παλαιότερα από:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="235"/>
        <location filename="../mainwindow.ui" line="372"/>
        <location filename="../mainwindow.ui" line="590"/>
        <source>Don&apos;t empty</source>
        <translation>Να μην αδειάσει</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="245"/>
        <location filename="../mainwindow.ui" line="622"/>
        <location filename="../mainwindow.ui" line="761"/>
        <location filename="../mainwindow.cpp" line="365"/>
        <location filename="../mainwindow.cpp" line="368"/>
        <location filename="../mainwindow.cpp" line="372"/>
        <source> days</source>
        <translation> ημέρες</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="264"/>
        <source>All users</source>
        <translation>Ολοι οι χρήστες</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="283"/>
        <source>Selected user</source>
        <translation>Επιλεγμένος χρήστης</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="331"/>
        <source>Clear APT Cache</source>
        <translation>Εκκαθάριση προσωρινής μνήμης πακέτων</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="343"/>
        <source>Old files</source>
        <translation>Παλιά αρχεία</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="362"/>
        <source>All files</source>
        <translation>Όλα τα αρχεία</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="404"/>
        <source>Graphical Tool for Analyzing Disk Usage</source>
        <translation>Γραφικό εργαλείο για την ανάλυση της χρήσης δίσκου</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="416"/>
        <source>Run Disk Usage Analyzer</source>
        <translation>Εκτέλεση του εργαλείου ανάλυσης της χρήσης δίσκου</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="430"/>
        <source>Schedule</source>
        <translation>Πρόγραμμα</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="442"/>
        <source>No automatic clean</source>
        <translation>Χωρίς προγραμματισμένο καθαρισμό</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="449"/>
        <source>At reboot</source>
        <translation>Σε επανεκκίνηση</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="456"/>
        <source>Daily</source>
        <translation>Καθημερινά</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="463"/>
        <source>Weekly</source>
        <translation>Εβδομαδιαία</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="470"/>
        <source>Monthly</source>
        <translation>Μηνιαία</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="499"/>
        <source>Free Disk Space for User</source>
        <translation>Απελευθέρωση χώρου του χρήστη</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="511"/>
        <location filename="../mainwindow.ui" line="527"/>
        <source>Select user to repair</source>
        <translation>Επιλέξτε χρήστη για την απελευθέρωση χώρου</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="514"/>
        <source>Select user:</source>
        <translation>Επιλογή χρήστη:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="543"/>
        <source>Delete Logs</source>
        <translation>Διαγραφή αρχείων καταγραφής</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="568"/>
        <source>All logs</source>
        <translation>Όλα τα αρχεία καταγραφής</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="606"/>
        <source>Old logs</source>
        <translation>Παλιά αρχεία καταγραφής</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="641"/>
        <source>Logs older than:</source>
        <translation>Αρχεία καταγραφής παλαιότερα από:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="664"/>
        <source>Removal tool</source>
        <translation>Εργαλείο αφαίρεσης</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="670"/>
        <source>Remove unused WiFi drivers</source>
        <translation>Αφαίρεση μη χρησιμοποιούμενων οδηγών WiFi</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="687"/>
        <source>List and select kernels to remove</source>
        <translation>Λίστα και επιλογή πυρήνων για αφαίρεση</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="707"/>
        <source>Clean Flatpak</source>
        <translation>Εκκαθάριση Flatpak</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="713"/>
        <source>Remove unused runtimes</source>
        <translation>Αφαίρεση αχρησιμοποίητων runtimes</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="729"/>
        <source>Clean Folders</source>
        <translation>Εκκαθάριση φακέλων</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="735"/>
        <source>Not accessed for:</source>
        <translation>Χωρίς πρόσβαση για:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="751"/>
        <source>Cache</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="787"/>
        <source>All (potentially dangerous)</source>
        <translation>Όλα (πιθανά επικίνδυνο)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="813"/>
        <source>Thumbnails</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="206"/>
        <location filename="../mainwindow.cpp" line="638"/>
        <source>Press any key to close</source>
        <translation>Πατήστε οποιοδήποτε πλήκτρο για να κλείσει</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="365"/>
        <location filename="../mainwindow.cpp" line="369"/>
        <location filename="../mainwindow.cpp" line="373"/>
        <source> day</source>
        <translation> ημέρα</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="508"/>
        <location filename="../mainwindow.cpp" line="510"/>
        <source>Done</source>
        <translation>Ολοκληρώθηκε</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="508"/>
        <source>Cleanup script will run at reboot</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="511"/>
        <source>Cleanup command done</source>
        <translation>Ο καθαρισμός ολοκληρώθηκε</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="511"/>
        <source>%1 MiB were freed</source>
        <translation>Απελευθερώθηκαν %1 MiB</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="519"/>
        <source>About</source>
        <translation>Περί</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="520"/>
        <source>Version: </source>
        <translation>Έκδοση: </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="522"/>
        <source>Quick and safe removal of old files</source>
        <translation>Γρήγορη και ασφαλής αφαίρεση παλιών αρχείων</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="524"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Πνευματικά δικαιώματα (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="525"/>
        <source>%1 License</source>
        <translation>Άδεια %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="532"/>
        <source>%1 Help</source>
        <translation>Βοήθεια %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="595"/>
        <source>Kernel currently in use: &lt;b&gt;%1&lt;/b&gt;</source>
        <translation>Πυρήνας σε χρήση: &lt;b&gt;%1&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="598"/>
        <source>Remove selected</source>
        <translation>Αφαίρεση επιλεγμένων</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="603"/>
        <source>Similar kernels that can be removed:</source>
        <translation>Παρόμοιοι πυρήνες που μπορούν να αφαιρεθούν:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="604"/>
        <source>Other kernels that can be removed:</source>
        <translation>Άλλοι πυρήνες που μπορούν να αφαιρεθούν:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="606"/>
        <source>&lt;b&gt;Nothing to remove.&lt;/b&gt; Cannot remove kernel in use.</source>
        <translation>&lt;b&gt;Καμία αφαίρεση.&lt;/b&gt; Δεν μπορεί να αφαιρεθεί πυρήνας σε χρήση.</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../about.cpp" line="70"/>
        <source>License</source>
        <translation>Άδεια</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="71"/>
        <location filename="../about.cpp" line="81"/>
        <source>Changelog</source>
        <translation>Αρχείο αλλαγών</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="72"/>
        <source>Cancel</source>
        <translation>Ακύρωση</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="94"/>
        <source>&amp;Close</source>
        <translation>&amp;Κλείσιμο</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="53"/>
        <source>Quick safe removal of old files</source>
        <translation>Γρήγορη και ασφαλής αφαίρεση παλιών αρχείων</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="79"/>
        <location filename="../main.cpp" line="87"/>
        <source>Error</source>
        <translation>Σφάλμα</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="80"/>
        <source>You seem to be logged in as root, please log out and log in as normal user to use this program.</source>
        <translation>Φαίνεται ότι έχετε συνδεθεί ως διαχειριστής, αποσυνδεθείτε και συνδεθείτε ως απλός χρήστης για να χρησιμοποιήσετε αυτό το πρόγραμμα.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="88"/>
        <source>You must run this program with admin access.</source>
        <translation>Πρέπει να τρέξετε αυτό το πρόγραμμα με δικαιώματα διαχειριστή.</translation>
    </message>
</context>
</TS>
